@@ -192,6 +192,14 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 		return TRUE;
 	}
 
+	for (i = 0; i < strlen (name); i++) {
+		if (!g_ascii_isalnum (name[i])) {
+			gnome_db_show_error (_("Data source names can only contain alphanumeric characters"));
+			gtk_widget_grab_focus (druid->priv->general_name);
+			return TRUE;
+		}
+	}
+
 	dsn_info = gnome_db_config_find_data_source (name);
 	if (dsn_info != NULL) {
 		gnome_db_config_free_data_source_info (dsn_info);
