@@ -114,6 +114,8 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_TYPES);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-within-transaction_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_WITHIN_TRANSACTION);
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-relations_24x24.png",
+                   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_RELATIONS);
 }
 
 /**
